@@ -59,6 +59,11 @@ BinOpMap = {
     },
 }
 
+BoolOpMap = {
+    And: plt.And,
+    Or: plt.Or,
+}
+
 
 ConstantMap = {
     str: plt.Text,
@@ -138,6 +143,20 @@ class UPLCCompiler(CompilingNodeTransformer):
             ),
         )
 
+    def visit_BoolOp(self, node: TypedBoolOp) -> plt.AST:
+        op = BoolOpMap.get(type(node.op))
+        assert len(node.values) >= 2, "Need to compare at least to values"
+        ops = op(
+            plt.Apply(self.visit(node.values[0]), plt.Var(STATEMONAD)),
+            plt.Apply(self.visit(node.values[1]), plt.Var(STATEMONAD)),
+        )
+        for v in node.values[2:]:
+            ops = op(ops, plt.Apply(self.visit(v), plt.Var(STATEMONAD)))
+        return plt.Lambda(
+            [STATEMONAD],
+            ops,
+        )
+
     def visit_Compare(self, node: TypedCompare) -> plt.AST:
         assert len(node.ops) == 1, "Only single comparisons are supported"
         assert len(node.comparators) == 1, "Only single comparisons are supported"
